Learn R Programming

SpaDES.core (version 1.0.9)

.runCodeChecks: Runs a series of code checks during simInit

Description

This uses custom tools and some optional tools in codetools package to check for function collisions with known, common function collisions (raster::stack, raster::scale). All outputs will be sent as messages.

Usage

.runCodeChecks(sim, m, k, hadPrevMessage = FALSE)

Arguments

sim

simList

m

module name

hadPrevMessage
message

rest of message

Value

A message with that starts with paste0(m, ":", message)