Checks that all parameters passed are used in a module, and that all parameters used in a module are passed.
checkParams(sim, coreParams, ...)# S4 method for simList,list
checkParams(sim, coreParams, ...)
Invisibly returns TRUE if every parameter supplied is used by a
module and every parameter a module uses was supplied; FALSE if
any are unmatched; and NA if the simulation has no user modules,
in which case there is nothing to check.
Sensible messages are produced identifying missing parameters.
A simList simulation object.
List of default core parameters.
Additional arguments. Not implemented.
Alex Chubaty