dot-params: Reserved module parameter names

.knownDotParamsR Documentation

Reserved module parameter names

Description

These are common parameter names that are reserved for specific use within modules.

Usage

.knownDotParams

Details

  • .plotInitialTime: the initial time for plotting;

  • .plotInterval: the interval between plots;

  • .plots: the types of plots to create (see types argument in Plots());

  • .saveInitialTime: the initial time for saving;

  • .saveInterval: the interval between saves;

  • .useCache: whether to use caching, or which events to cache;

  • .useCacheArgs: optional named list (keyed by event name) of extra arguments passed to reproducible::Cache() for that event (e.g. cacheId, useCloud, cloudFolderID); enables a developer to pin a fixed cloud cache key for a deterministic event;

  • .useParallel: whether to use parallel processing, or the number of parallel cores to use;


SpaDES.core documentation built on May 23, 2026, 5:07 p.m.