Learn R Programming

SpaDES.core (version 3.2.1)

globals: Get and set global simulation parameters

Description

globals, and the alias G, accesses or sets the "globals" in the simList. This currently is not an explicit slot in the simList, but it is a .globals element in the params slot of the simList.

Usage

globals(sim)

# S4 method for simList globals(sim)

globals(sim) <- value

# S4 method for simList globals(sim) <- value

G(sim)

# S4 method for simList G(sim)

G(sim) <- value

# S4 method for simList G(sim) <- value

Value

For globals() and G(), a named list of the global parameters, i.e., the .globals element of the params slot. For the replacement methods globals<- and G<-, the updated simList, with any module parameters that take their value from a global re-synchronised.

Arguments

sim

A simList object from which to extract element(s) or in which to replace element(s).

value

The parameter value to be set (in the corresponding module and param).

See Also

SpaDES.core-package, specifically the section 1.2.1 on Simulation Parameters.

Other functions to access elements of a 'simList' object: .addDepends(), checkpointFile(), envir(), events(), inputs(), modules(), objs(), packages(), params(), paths(), progressInterval(), times()