simList and ancillary filesLoading a simList from file can be problematic as there are non-standard
objects that must be rebuilt. See description in saveSimList() for details.
unzipSimList is a convenience wrapper around unzip and loadSimList where
all the files are correctly identified and passed to
loadSimList(..., otherFiles = xxx). See zipSimList for details.
loadSimList(filename, paths = getPaths(), otherFiles = "")unzipSimList(zipfile, load = TRUE, paths = getPaths(), ...)
Character giving the name of a saved simulation file
A list of character vectors for all the simList paths. When
loading a simList, this will replace the paths of everything to
these new paths. Experimental still.
A character vector of (absolute) file names locating each of the
existing file-backed Raster* files that are the real paths for the possibly
incorrect paths in Filenames(sim) if the the file being read in is from
a different computer, path, or drive. This could be the output from unzipSimList
(which is calls loadSimList internally, passing the unzipped filenames)
Filename of a zipped simList
Logical. If TRUE, the default, then the simList will
also be loaded into R.
passed to unzip
loadSimList(): A simList object.
unzipSimList(): Either a character vector of file names unzipped (if load = FALSE),
or a simList object.
If cache is used, it is likely that it should be trimmed before
zipping, to include only cache elements that are relevant.