quickCheck: The 'SpaDES.core' variable to switch between quick and robust...

.quickCheckR Documentation

The SpaDES.core variable to switch between quick and robust checking

Description

A variable that can be use by module developers and model users to switch between a quick check of functions like downloadData, Cache. The module developer must actually use this in their code.

Usage

.quickCheck

SpaDES.core documentation built on May 23, 2026, 5:07 p.m.