Learn R Programming

SpaDES.core (version 3.2.1)

savedSimEnv: Retrieve environment for saving interrupted simulations

Description

If the user sets options(reproducible.memoisePersist = TRUE), the global environment will be used, otherwise, a package environment.

Usage

savedSimEnv(envir = .GlobalEnv)

Value

An environment: envir if options(reproducible.memoisePersist = TRUE), otherwise the SpaDES.core package environment used to hold the saved simList.

Arguments

envir

an environment to use to store the .sim (simList) object. default is to use the user's global environment (.GlobalEnv).