sim argument for the restart functionsShared preamble of restartSpades() and restartSimInit(): announce the
experimental status, default a missing sim to the stashed savedSimEnv()$.sim,
load it from disk if a filename was given, and assert it is a simList.
.restartResolveSim(sim, verbose)A simList.
NULL, a filename, or a simList (as passed to the restart functions).
Numeric verbosity, passed to messageVerbose().