Learn R Programming

SpaDES.core (version 1.0.9)

objectDiagram: Simulation object dependency diagram

Description

Create a sequence diagram illustrating the data object dependencies of a simulation. Offers a more detailed view of specific objects than does plotting the depsEdgeList directly with moduleDiagram.

Usage

objectDiagram(sim, ...)

# S4 method for simList objectDiagram(sim, ...)

Arguments

sim

A simList object (typically corresponding to a completed simulation).

...

Additional arguments passed to DiagrammeR::mermaid. Useful for specifying height and width.

Value

Plots a sequence diagram, invisibly returning a DiagrammeR::mermaid object.

See Also

DiagrammeR::mermaid.

Examples

Run this code
# NOT RUN {
objectDiagram(sim)
# if there are lots of objects, may need to increase width and/or height
objectDiagram(sim, height = 3000, width = 3000)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab