If the user sets options(reproducible.memoisePersist = TRUE),
the global environment will be used, otherwise, a package environment.
savedSimEnv(envir = .GlobalEnv)An environment: envir if options(reproducible.memoisePersist = TRUE),
otherwise the SpaDES.core package environment used to hold the saved simList.
an environment to use to store the .sim (simList) object.
default is to use the user's global environment (.GlobalEnv).