singularPlural: Pick the singular or plural form for a message
Description
Pick the singular or plural form for a message
Usage
singularPlural(singPlur, l, v)isAre(l, v)
Value
One element of singPlur.
Arguments
- singPlur
Length-2 character vector: the singular form, then the plural.
- l
An object whose length is the count.
- v
The count itself. Takes precedence over l when both are supplied.