Learn R Programming

SpaDES.core (version 1.0.9)

updateList: Update elements of a named list with elements of a second named list

Description

Being deprecated. Use modifyList (which can not handle NULL) or modifyList2 for case with >2 lists and can handle NULL lists.

Usage

updateList(x, y)

Arguments

x

a named list

y

a named list

Value

A named list, with elements sorted by name. The values of matching elements in list y replace the values in list x.